@@ -105,6 +105,18 @@ make_new_data <- function(model, pred, pred.values = NULL, at = NULL,
     }
   }
   
+  # When a user provides a matrix column variable, most commonly the result
+  # of using the `scale()` function, the `predict()` functions fail if the
+  # new data use a numeric variable instead.
+  var_classes <- sapply(names(new_data), function(x) {
+    "matrix" %in% class(data[[x]])
+  })
+  if (any(var_classes)) {
+    for (var in names(var_classes)[var_classes]) {
+      new_data[[var]] <- as.matrix(new_data[[var]])
+    }
+  }
+  
   return(tibble::as_tibble(new_data))
   
 }
@@ -212,7 +224,7 @@ get_data <- function(model, formula = NULL, warn = TRUE, ...) {
   if ("svyglm" %in% class(model)) {
     d <- model$survey.design$variables
     wname <- "(weights)"
-    d[wname] <- weights(model$survey.design)
+    d[wname] <- weights(model$survey.design, type = "sampling")
   } else {
     d <- model.frame(model)
   }
@@ -510,7 +522,11 @@ pred_values <- function(x, length = 100) {
   if (is.numeric(x)) {
     seq(min(x, na.rm = TRUE), max(x, na.rm = TRUE), length.out = length)
   } else {
-    unique(x) %not% NA
+    if (is.factor(x)) {
+      factor(levels(x), levels = levels(x))
+    } else {
+        unique(x) %not% NA
+    }
   }
 }
 
